Module Name: src
Committed By: joerg
Date: Tue Feb 28 17:09:32 UTC 2012
Modified Files:
src/external/bsd/llvm: Makefile.inc
src/external/bsd/llvm/bin/clang: Makefile
src/external/bsd/llvm/config/llvm/Config: AsmParsers.def
Disassemblers.def config.h llvm-config.h
src/external/bsd/llvm/config/llvm/Support: DataTypes.h
src/external/bsd/llvm/include: Makefile
src/external/bsd/llvm/lib: Makefile
src/external/bsd/llvm/lib/libLLVMCodeGen: Makefile
src/external/bsd/llvm/lib/libLLVMInstrumentation: Makefile
src/external/bsd/llvm/lib/libLLVMMipsCodeGen: Makefile
src/external/bsd/llvm/lib/libLLVMSelectionDAG: Makefile
src/external/bsd/llvm/lib/libLLVMSupport: Makefile
src/external/bsd/llvm/lib/libclangAST: Makefile
src/external/bsd/llvm/lib/libclangDriver: Makefile
src/external/bsd/llvm/lib/libclangFrontend: Makefile
src/external/bsd/llvm/lib/libclangRewrite: Makefile
src/external/bsd/llvm/lib/libclangSema: Makefile
src/external/bsd/llvm/lib/libclangStaticAnalyzerCheckers: Makefile
src/tools/llvm: Makefile
Added Files:
src/external/bsd/llvm/config/clang/Config: config.h
src/external/bsd/llvm/lib/libLLVMVectorize: Makefile
src/tools/llvm-lib/libLLVMVectorize: Makefile
Log Message:
Update LLVM/Clang snapshot to r151411. This brings in Lambda support for
C++11 and a new literal format string check to catch variadic argument
functions.
To generate a diff of this commit:
cvs rdiff -u -r1.29 -r1.30 src/external/bsd/llvm/Makefile.inc
cvs rdiff -u -r1.17 -r1.18 src/external/bsd/llvm/bin/clang/Makefile
cvs rdiff -u -r0 -r1.1 src/external/bsd/llvm/config/clang/Config/config.h
cvs rdiff -u -r1.2 -r1.3 \
src/external/bsd/llvm/config/llvm/Config/AsmParsers.def \
src/external/bsd/llvm/config/llvm/Config/Disassemblers.def
cvs rdiff -u -r1.6 -r1.7 src/external/bsd/llvm/config/llvm/Config/config.h
cvs rdiff -u -r1.5 -r1.6 \
src/external/bsd/llvm/config/llvm/Config/llvm-config.h
cvs rdiff -u -r1.1 -r1.2 \
src/external/bsd/llvm/config/llvm/Support/DataTypes.h
cvs rdiff -u -r1.6 -r1.7 src/external/bsd/llvm/include/Makefile
cvs rdiff -u -r1.18 -r1.19 src/external/bsd/llvm/lib/Makefile
cvs rdiff -u -r1.14 -r1.15 src/external/bsd/llvm/lib/libLLVMCodeGen/Makefile
cvs rdiff -u -r1.3 -r1.4 \
src/external/bsd/llvm/lib/libLLVMInstrumentation/Makefile
cvs rdiff -u -r1.7 -r1.8 \
src/external/bsd/llvm/lib/libLLVMMipsCodeGen/Makefile
cvs rdiff -u -r1.2 -r1.3 \
src/external/bsd/llvm/lib/libLLVMSelectionDAG/Makefile
cvs rdiff -u -r1.8 -r1.9 src/external/bsd/llvm/lib/libLLVMSupport/Makefile
cvs rdiff -u -r0 -r1.1 src/external/bsd/llvm/lib/libLLVMVectorize/Makefile
cvs rdiff -u -r1.3 -r1.4 src/external/bsd/llvm/lib/libclangAST/Makefile
cvs rdiff -u -r1.2 -r1.3 src/external/bsd/llvm/lib/libclangDriver/Makefile
cvs rdiff -u -r1.10 -r1.11 \
src/external/bsd/llvm/lib/libclangFrontend/Makefile
cvs rdiff -u -r1.1 -r1.2 src/external/bsd/llvm/lib/libclangRewrite/Makefile
cvs rdiff -u -r1.7 -r1.8 src/external/bsd/llvm/lib/libclangSema/Makefile
cvs rdiff -u -r1.11 -r1.12 \
src/external/bsd/llvm/lib/libclangStaticAnalyzerCheckers/Makefile
cvs rdiff -u -r1.11 -r1.12 src/tools/llvm/Makefile
cvs rdiff -u -r0 -r1.1 src/tools/llvm-lib/libLLVMVectorize/Makefile
Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.
Modified files:
Index: src/external/bsd/llvm/Makefile.inc
diff -u src/external/bsd/llvm/Makefile.inc:1.29 src/external/bsd/llvm/Makefile.inc:1.30
--- src/external/bsd/llvm/Makefile.inc:1.29 Tue Jan 17 15:51:55 2012
+++ src/external/bsd/llvm/Makefile.inc Tue Feb 28 17:09:29 2012
@@ -1,12 +1,12 @@
-# $NetBSD: Makefile.inc,v 1.29 2012/01/17 15:51:55 joerg Exp $
+# $NetBSD: Makefile.inc,v 1.30 2012/02/28 17:09:29 joerg Exp $
.if !defined(LLVM_TOPLEVEL_MK)
LLVM_TOPLEVEL_MK=
.include <bsd.own.mk>
-LLVM_REVISION= 148262
-CLANG_REVISION= 148262
+LLVM_REVISION= 151411
+CLANG_REVISION= 151411
LLVM_SRCDIR:= ${.PARSEDIR}/dist/llvm
CLANG_SRCDIR:= ${.PARSEDIR}/dist/clang
@@ -18,15 +18,23 @@ CPPFLAGS+= -I. -I${LLVM_SRCDIR}/include
.if defined(HOSTLIB) || defined(HOSTPROG)
LLVM_INCLUDE_CONFIG= ${LLVM_TOOLCONF_OBJDIR}/config/include
+CLANG_INCLUDE_CONFIG= ${LLVM_TOOLCONF_OBJDIR}/config/tools/clang/include
LLVM_INCLUDE_OBJDIR!= cd ${NETBSDSRCDIR}/tools/llvm-include && ${PRINTOBJDIR}
LLVM_TOOLCONF_OBJDIR!= cd ${NETBSDSRCDIR}/tools/llvm && ${PRINTOBJDIR}
HOST_CPPFLAGS+= ${CPPFLAGS}
HOST_CXXFLAGS+= -O2 -g
.else
LLVM_INCLUDE_CONFIG= ${LLVM_TOPLEVEL}/config
+CLANG_INCLUDE_CONFIG= ${LLVM_TOPLEVEL}/config
LLVM_INCLUDE_OBJDIR!= cd ${LLVM_TOPLEVEL}/include && ${PRINTOBJDIR}
CPPFLAGS+= -DLLVM_DEFAULT_TARGET_TRIPLE="\"${MACHINE_GNU_PLATFORM}\""
.endif
-CPPFLAGS+= -I${LLVM_INCLUDE_OBJDIR} -I${LLVM_INCLUDE_CONFIG}
+CPPFLAGS+= -I${LLVM_INCLUDE_OBJDIR} -I${LLVM_INCLUDE_CONFIG} \
+ -I${CLANG_INCLUDE_CONFIG}
+
+# ./configure --enable-targets=x86,powerpc,sparc,arm,mips \
+# --with-c-include-dirs=/usr/include/clang-3.0:/usr/include \
+# --disable-timestamps --prefix=/usr --sysconfdir=/etc/llvm \
+# --disable-threads
.endif
Index: src/external/bsd/llvm/bin/clang/Makefile
diff -u src/external/bsd/llvm/bin/clang/Makefile:1.17 src/external/bsd/llvm/bin/clang/Makefile:1.18
--- src/external/bsd/llvm/bin/clang/Makefile:1.17 Wed Jan 18 16:53:09 2012
+++ src/external/bsd/llvm/bin/clang/Makefile Tue Feb 28 17:09:29 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.17 2012/01/18 16:53:09 joerg Exp $
+# $NetBSD: Makefile,v 1.18 2012/02/28 17:09:29 joerg Exp $
PROG_CXX= clang
NOMAN= yes
@@ -66,6 +66,7 @@ LLVM_LIBS+= \
SelectionDAG \
AsmPrinter \
CodeGen \
+ Vectorize \
Target \
InstCombine \
Instrumentation \
Index: src/external/bsd/llvm/config/llvm/Config/AsmParsers.def
diff -u src/external/bsd/llvm/config/llvm/Config/AsmParsers.def:1.2 src/external/bsd/llvm/config/llvm/Config/AsmParsers.def:1.3
--- src/external/bsd/llvm/config/llvm/Config/AsmParsers.def:1.2 Tue Jul 5 17:22:21 2011
+++ src/external/bsd/llvm/config/llvm/Config/AsmParsers.def Tue Feb 28 17:09:30 2012
@@ -24,6 +24,6 @@
# error Please define the macro LLVM_ASM_PARSER(TargetName)
#endif
-LLVM_ASM_PARSER(X86) LLVM_ASM_PARSER(ARM)
+LLVM_ASM_PARSER(X86) LLVM_ASM_PARSER(ARM) LLVM_ASM_PARSER(Mips)
#undef LLVM_ASM_PARSER
Index: src/external/bsd/llvm/config/llvm/Config/Disassemblers.def
diff -u src/external/bsd/llvm/config/llvm/Config/Disassemblers.def:1.2 src/external/bsd/llvm/config/llvm/Config/Disassemblers.def:1.3
--- src/external/bsd/llvm/config/llvm/Config/Disassemblers.def:1.2 Tue Jul 5 17:22:22 2011
+++ src/external/bsd/llvm/config/llvm/Config/Disassemblers.def Tue Feb 28 17:09:30 2012
@@ -9,7 +9,7 @@
//
// This file enumerates all of the assembly-language parsers
// supported by this build of LLVM. Clients of this file should define
-// the LLVM_ASM_PARSER macro to be a function-like macro with a
+// the LLVM_DISASSEMBLER macro to be a function-like macro with a
// single parameter (the name of the target whose assembly can be
// generated); including this file will then enumerate all of the
// targets with assembly parsers.
Index: src/external/bsd/llvm/config/llvm/Config/config.h
diff -u src/external/bsd/llvm/config/llvm/Config/config.h:1.6 src/external/bsd/llvm/config/llvm/Config/config.h:1.7
--- src/external/bsd/llvm/config/llvm/Config/config.h:1.6 Wed Jan 11 23:24:46 2012
+++ src/external/bsd/llvm/config/llvm/Config/config.h Tue Feb 28 17:09:30 2012
@@ -5,23 +5,11 @@
#define CONFIG_H
/* Bug report URL. */
-#define BUG_REPORT_URL "http://llvm.org"
+#define BUG_REPORT_URL "http://llvm.org/bugs/"
/* Relative directory for resource files */
#define CLANG_RESOURCE_DIR ""
-/* 32 bit multilib directory. */
-#define CXX_INCLUDE_32BIT_DIR ""
-
-/* 64 bit multilib directory. */
-#define CXX_INCLUDE_64BIT_DIR ""
-
-/* Arch the libstdc++ headers. */
-#define CXX_INCLUDE_ARCH ""
-
-/* Directory with the libstdc++ headers. */
-#define CXX_INCLUDE_ROOT ""
-
/* Directories clang will search for headers */
#define C_INCLUDE_DIRS "/usr/include/clang-3.0:/usr/include"
@@ -31,11 +19,11 @@
/* Define if position independent code is enabled */
#define ENABLE_PIC 1
-/* Define if threads enabled */
-#define ENABLE_THREADS 1
-
/* Define if timestamp information (e.g., __DATE___) is allowed */
-#define ENABLE_TIMESTAMPS 1
+#define ENABLE_TIMESTAMPS 0
+
+/* Directory where gcc is installed. */
+#define GCC_INSTALL_PREFIX ""
/* Define to 1 if you have the `argz_append' function. */
/* #undef HAVE_ARGZ_APPEND */
@@ -211,7 +199,7 @@
/* #undef HAVE_LIBPSAPI */
/* Define to 1 if you have the `pthread' library (-lpthread). */
-#define HAVE_LIBPTHREAD 1
+/* #undef HAVE_LIBPTHREAD */
/* Define to 1 if you have the `udis86' library (-ludis86). */
/* #undef HAVE_LIBUDIS86 */
@@ -291,11 +279,14 @@
#define HAVE_OPENDIR 1
/* Define to 1 if you have the `posix_spawn' function. */
-/* #undef HAVE_POSIX_SPAWN */
+#define HAVE_POSIX_SPAWN 1
/* Define to 1 if you have the `powf' function. */
#define HAVE_POWF 1
+/* Define to 1 if you have the `pread' function. */
+#define HAVE_PREAD 1
+
/* Define if libtool can extract symbol lists from object files. */
#define HAVE_PRELOADED_SYMBOLS 1
@@ -303,16 +294,16 @@
#define HAVE_PRINTF_A 1
/* Have pthread_getspecific */
-#define HAVE_PTHREAD_GETSPECIFIC 1
+/* #undef HAVE_PTHREAD_GETSPECIFIC */
/* Define to 1 if you have the <pthread.h> header file. */
-#define HAVE_PTHREAD_H 1
+/* #undef HAVE_PTHREAD_H */
/* Have pthread_mutex_lock */
-#define HAVE_PTHREAD_MUTEX_LOCK 1
+/* #undef HAVE_PTHREAD_MUTEX_LOCK */
/* Have pthread_rwlock_init */
-#define HAVE_PTHREAD_RWLOCK_INIT 1
+/* #undef HAVE_PTHREAD_RWLOCK_INIT */
/* Define to 1 if srand48/lrand48/drand48 exist in <stdlib.h> */
#define HAVE_RAND48 1
@@ -539,7 +530,7 @@
#define LLVM_BINDIR "/usr/bin"
/* Time at which LLVM was configured */
-#define LLVM_CONFIGTIME "Thu Nov 3 00:22:51 CET 2011"
+#define LLVM_CONFIGTIME "Tue Feb 28 15:53:15 UTC 2012"
/* Installation directory for data files */
#define LLVM_DATADIR "/usr/share/llvm"
@@ -552,6 +543,9 @@
/* Installation directory for documentation */
#define LLVM_DOCSDIR "/usr/share/doc/llvm"
+/* Define if threads enabled */
+#define LLVM_ENABLE_THREADS 0
+
/* Installation directory for config files */
#define LLVM_ETCDIR "/usr/etc/llvm"
@@ -624,6 +618,12 @@
/* Installation prefix directory */
#define LLVM_PREFIX "/usr"
+/* Major version of the LLVM API */
+#define LLVM_VERSION_MAJOR 3
+
+/* Minor version of the LLVM API */
+#define LLVM_VERSION_MINOR 1
+
/* Define if the OS needs help to load dependent libraries for dlopen(). */
/* #undef LTDL_DLOPEN_DEPLIBS */
@@ -649,16 +649,16 @@
/* #undef NEED_USCORE */
/* Define to the address where bug reports for this package should be sent. */
-#define PACKAGE_BUGREPORT "[email protected]"
+#define PACKAGE_BUGREPORT "http://llvm.org/bugs/"
/* Define to the full name of this package. */
-#define PACKAGE_NAME "llvm"
+#define PACKAGE_NAME "LLVM"
/* Define to the full name and version of this package. */
-#define PACKAGE_STRING "llvm 3.1svn"
+#define PACKAGE_STRING "LLVM 3.1svn"
/* Define to the one symbol short name of this package. */
-#define PACKAGE_TARNAME "-llvm-"
+#define PACKAGE_TARNAME "llvm"
/* Define to the version of this package. */
#define PACKAGE_VERSION "3.1svn"
Index: src/external/bsd/llvm/config/llvm/Config/llvm-config.h
diff -u src/external/bsd/llvm/config/llvm/Config/llvm-config.h:1.5 src/external/bsd/llvm/config/llvm/Config/llvm-config.h:1.6
--- src/external/bsd/llvm/config/llvm/Config/llvm-config.h:1.5 Wed Jan 11 23:24:46 2012
+++ src/external/bsd/llvm/config/llvm/Config/llvm-config.h Tue Feb 28 17:09:30 2012
@@ -21,25 +21,28 @@
#define LLVM_BINDIR "/usr/bin"
/* Time at which LLVM was configured */
-#define LLVM_CONFIGTIME "Thu Nov 3 00:22:51 CET 2011"
+#define LLVM_CONFIGTIME "Tue Feb 28 15:53:15 UTC 2012"
/* Installation directory for data files */
#define LLVM_DATADIR "/usr/share/llvm"
+/* Target triple LLVM will generate code for by default */
+#if 0
+#define LLVM_DEFAULT_TARGET_TRIPLE "x86_64--netbsd"
+#endif
+
/* Installation directory for documentation */
#define LLVM_DOCSDIR "/usr/share/doc/llvm"
+/* Define if threads enabled */
+#define LLVM_ENABLE_THREADS 0
+
/* Installation directory for config files */
#define LLVM_ETCDIR "/usr/etc/llvm"
/* Has gcc/MSVC atomic intrinsics */
#define LLVM_HAS_ATOMICS 1
-/* Host triple we were built on */
-#if 0
-#define LLVM_DEFAULT_TARGET_TRIPLE "x86_64--netbsd"
-#endif
-
/* Installation directory for include files */
#define LLVM_INCLUDEDIR "/usr/include"
@@ -106,4 +109,10 @@
/* Installation prefix directory */
#define LLVM_PREFIX "/usr"
+/* Major version of the LLVM API */
+#define LLVM_VERSION_MAJOR 3
+
+/* Minor version of the LLVM API */
+#define LLVM_VERSION_MINOR 1
+
#endif
Index: src/external/bsd/llvm/include/Makefile
diff -u src/external/bsd/llvm/include/Makefile:1.6 src/external/bsd/llvm/include/Makefile:1.7
--- src/external/bsd/llvm/include/Makefile:1.6 Wed Jan 11 23:24:46 2012
+++ src/external/bsd/llvm/include/Makefile Tue Feb 28 17:09:30 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.6 2012/01/11 23:24:46 joerg Exp $
+# $NetBSD: Makefile,v 1.7 2012/02/28 17:09:30 joerg Exp $
.include <bsd.init.mk>
@@ -58,6 +58,7 @@ CLANG_TABLEGEN_OUTPUT.Attr.td= \
clang/Basic/AttrList.inc|-gen-clang-attr-list \
clang/Lex/AttrSpellings.inc|-gen-clang-attr-spelling-list \
clang/Parse/AttrLateParsed.inc|-gen-clang-attr-late-parsed-list \
+ clang/Sema/AttrTemplateInstantiate.inc|-gen-clang-attr-template-instantiate \
clang/Serialization/AttrPCHRead.inc|-gen-clang-attr-pch-read \
clang/Serialization/AttrPCHWrite.inc|-gen-clang-attr-pch-write
Index: src/external/bsd/llvm/lib/Makefile
diff -u src/external/bsd/llvm/lib/Makefile:1.18 src/external/bsd/llvm/lib/Makefile:1.19
--- src/external/bsd/llvm/lib/Makefile:1.18 Tue Jan 17 15:51:55 2012
+++ src/external/bsd/llvm/lib/Makefile Tue Feb 28 17:09:30 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.18 2012/01/17 15:51:55 joerg Exp $
+# $NetBSD: Makefile,v 1.19 2012/02/28 17:09:30 joerg Exp $
.include <bsd.own.mk>
@@ -26,6 +26,7 @@ SUBDIR= \
libLLVMTableGen \
libLLVMTarget \
libLLVMTransformsUtils \
+ libLLVMVectorize \
libLLVMARMCodeGen \
libLLVMMipsCodeGen \
libLLVMPowerPCCodeGen \
Index: src/external/bsd/llvm/lib/libLLVMCodeGen/Makefile
diff -u src/external/bsd/llvm/lib/libLLVMCodeGen/Makefile:1.14 src/external/bsd/llvm/lib/libLLVMCodeGen/Makefile:1.15
--- src/external/bsd/llvm/lib/libLLVMCodeGen/Makefile:1.14 Tue Jan 17 15:51:55 2012
+++ src/external/bsd/llvm/lib/libLLVMCodeGen/Makefile Tue Feb 28 17:09:30 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.14 2012/01/17 15:51:55 joerg Exp $
+# $NetBSD: Makefile,v 1.15 2012/02/28 17:09:30 joerg Exp $
LIB= LLVMCodeGen
@@ -15,6 +15,7 @@ SRCS+= AggressiveAntiDepBreaker.cpp \
CodeGen.cpp \
CodePlacementOpt.cpp \
CriticalAntiDepBreaker.cpp \
+ DFAPacketizer.cpp \
DeadMachineInstructionElim.cpp \
DwarfEHPrepare.cpp \
EdgeBundles.cpp \
Index: src/external/bsd/llvm/lib/libLLVMInstrumentation/Makefile
diff -u src/external/bsd/llvm/lib/libLLVMInstrumentation/Makefile:1.3 src/external/bsd/llvm/lib/libLLVMInstrumentation/Makefile:1.4
--- src/external/bsd/llvm/lib/libLLVMInstrumentation/Makefile:1.3 Fri Nov 18 15:56:54 2011
+++ src/external/bsd/llvm/lib/libLLVMInstrumentation/Makefile Tue Feb 28 17:09:30 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.3 2011/11/18 15:56:54 joerg Exp $
+# $NetBSD: Makefile,v 1.4 2012/02/28 17:09:30 joerg Exp $
LIB= LLVMInstrumentation
@@ -12,7 +12,8 @@ SRCS+= AddressSanitizer.cpp \
Instrumentation.cpp \
OptimalEdgeProfiling.cpp \
PathProfiling.cpp \
- ProfilingUtils.cpp
+ ProfilingUtils.cpp \
+ ThreadSanitizer.cpp
.if defined(HOSTLIB)
.include <bsd.hostlib.mk>
Index: src/external/bsd/llvm/lib/libLLVMMipsCodeGen/Makefile
diff -u src/external/bsd/llvm/lib/libLLVMMipsCodeGen/Makefile:1.7 src/external/bsd/llvm/lib/libLLVMMipsCodeGen/Makefile:1.8
--- src/external/bsd/llvm/lib/libLLVMMipsCodeGen/Makefile:1.7 Wed Jan 11 23:24:47 2012
+++ src/external/bsd/llvm/lib/libLLVMMipsCodeGen/Makefile Tue Feb 28 17:09:30 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.7 2012/01/11 23:24:47 joerg Exp $
+# $NetBSD: Makefile,v 1.8 2012/02/28 17:09:30 joerg Exp $
LIB= LLVMMipsCodeGen
@@ -6,7 +6,8 @@ LIB= LLVMMipsCodeGen
.PATH: ${LLVM_SRCDIR}/lib/Target/Mips
-SRCS+= MipsAsmPrinter.cpp \
+SRCS+= MipsAnalyzeImmediate.cpp \
+ MipsAsmPrinter.cpp \
MipsCodeEmitter.cpp \
MipsDelaySlotFiller.cpp \
MipsEmitGPRestore.cpp \
Index: src/external/bsd/llvm/lib/libLLVMSelectionDAG/Makefile
diff -u src/external/bsd/llvm/lib/libLLVMSelectionDAG/Makefile:1.2 src/external/bsd/llvm/lib/libLLVMSelectionDAG/Makefile:1.3
--- src/external/bsd/llvm/lib/libLLVMSelectionDAG/Makefile:1.2 Thu Nov 3 17:52:54 2011
+++ src/external/bsd/llvm/lib/libLLVMSelectionDAG/Makefile Tue Feb 28 17:09:30 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.2 2011/11/03 17:52:54 joerg Exp $
+# $NetBSD: Makefile,v 1.3 2012/02/28 17:09:30 joerg Exp $
LIB= LLVMSelectionDAG
@@ -17,9 +17,11 @@ SRCS+= DAGCombiner.cpp \
LegalizeTypesGeneric.cpp \
LegalizeVectorOps.cpp \
LegalizeVectorTypes.cpp \
+ ResourcePriorityQueue.cpp \
ScheduleDAGFast.cpp \
ScheduleDAGRRList.cpp \
ScheduleDAGSDNodes.cpp \
+ ScheduleDAGVLIW.cpp \
SelectionDAG.cpp \
SelectionDAGBuilder.cpp \
SelectionDAGISel.cpp \
Index: src/external/bsd/llvm/lib/libLLVMSupport/Makefile
diff -u src/external/bsd/llvm/lib/libLLVMSupport/Makefile:1.8 src/external/bsd/llvm/lib/libLLVMSupport/Makefile:1.9
--- src/external/bsd/llvm/lib/libLLVMSupport/Makefile:1.8 Wed Jan 11 23:24:48 2012
+++ src/external/bsd/llvm/lib/libLLVMSupport/Makefile Tue Feb 28 17:09:31 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.8 2012/01/11 23:24:48 joerg Exp $
+# $NetBSD: Makefile,v 1.9 2012/02/28 17:09:31 joerg Exp $
LIB= LLVMSupport
@@ -19,6 +19,7 @@ SRCS+= APFloat.cpp \
ConstantRange.cpp \
CrashRecoveryContext.cpp \
DataExtractor.cpp \
+ DataStream.cpp \
Debug.cpp \
DeltaAlgorithm.cpp \
DAGDeltaAlgorithm.cpp \
@@ -34,6 +35,7 @@ SRCS+= APFloat.cpp \
IsInf.cpp \
IsNAN.cpp \
JSONParser.cpp \
+ LockFileManager.cpp \
ManagedStatic.cpp \
MemoryBuffer.cpp \
MemoryObject.cpp \
@@ -44,6 +46,7 @@ SRCS+= APFloat.cpp \
SmallVector.cpp \
SourceMgr.cpp \
Statistic.cpp \
+ StreamableMemoryObject.cpp \
StringExtras.cpp \
StringMap.cpp \
StringPool.cpp \
Index: src/external/bsd/llvm/lib/libclangAST/Makefile
diff -u src/external/bsd/llvm/lib/libclangAST/Makefile:1.3 src/external/bsd/llvm/lib/libclangAST/Makefile:1.4
--- src/external/bsd/llvm/lib/libclangAST/Makefile:1.3 Tue Oct 11 13:54:00 2011
+++ src/external/bsd/llvm/lib/libclangAST/Makefile Tue Feb 28 17:09:31 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.3 2011/10/11 13:54:00 joerg Exp $
+# $NetBSD: Makefile,v 1.4 2012/02/28 17:09:31 joerg Exp $
LIB= clangAST
@@ -31,6 +31,7 @@ SRCS+= APValue.cpp \
InheritViz.cpp \
ItaniumCXXABI.cpp \
ItaniumMangle.cpp \
+ LambdaMangleContext.cpp \
Mangle.cpp \
MicrosoftCXXABI.cpp \
MicrosoftMangle.cpp \
Index: src/external/bsd/llvm/lib/libclangDriver/Makefile
diff -u src/external/bsd/llvm/lib/libclangDriver/Makefile:1.2 src/external/bsd/llvm/lib/libclangDriver/Makefile:1.3
--- src/external/bsd/llvm/lib/libclangDriver/Makefile:1.2 Mon Dec 19 14:07:40 2011
+++ src/external/bsd/llvm/lib/libclangDriver/Makefile Tue Feb 28 17:09:31 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.2 2011/12/19 14:07:40 joerg Exp $
+# $NetBSD: Makefile,v 1.3 2012/02/28 17:09:31 joerg Exp $
LIB= clangDriver
@@ -14,7 +14,6 @@ SRCS+= Action.cpp \
Compilation.cpp \
Driver.cpp \
DriverOptions.cpp \
- HostInfo.cpp \
Job.cpp \
Option.cpp \
OptTable.cpp \
Index: src/external/bsd/llvm/lib/libclangFrontend/Makefile
diff -u src/external/bsd/llvm/lib/libclangFrontend/Makefile:1.10 src/external/bsd/llvm/lib/libclangFrontend/Makefile:1.11
--- src/external/bsd/llvm/lib/libclangFrontend/Makefile:1.10 Wed Jan 11 23:24:48 2012
+++ src/external/bsd/llvm/lib/libclangFrontend/Makefile Tue Feb 28 17:09:31 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.10 2012/01/11 23:24:48 joerg Exp $
+# $NetBSD: Makefile,v 1.11 2012/02/28 17:09:31 joerg Exp $
LIB= clangFrontend
@@ -16,6 +16,7 @@ SRCS+= ASTConsumers.cpp \
CompilerInvocation.cpp \
CreateInvocationFromCommandLine.cpp \
DependencyFile.cpp \
+ DependencyGraph.cpp \
DiagnosticRenderer.cpp \
FrontendAction.cpp \
FrontendActions.cpp \
@@ -24,6 +25,7 @@ SRCS+= ASTConsumers.cpp \
InitHeaderSearch.cpp \
InitPreprocessor.cpp \
LangStandards.cpp \
+ LayoutOverrideSource.cpp \
LogDiagnosticPrinter.cpp \
MultiplexConsumer.cpp \
PrintPreprocessedOutput.cpp \
Index: src/external/bsd/llvm/lib/libclangRewrite/Makefile
diff -u src/external/bsd/llvm/lib/libclangRewrite/Makefile:1.1 src/external/bsd/llvm/lib/libclangRewrite/Makefile:1.2
--- src/external/bsd/llvm/lib/libclangRewrite/Makefile:1.1 Sun Feb 6 01:14:09 2011
+++ src/external/bsd/llvm/lib/libclangRewrite/Makefile Tue Feb 28 17:09:31 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.1 2011/02/06 01:14:09 joerg Exp $
+# $NetBSD: Makefile,v 1.2 2012/02/28 17:09:31 joerg Exp $
LIB= clangRewrite
@@ -12,6 +12,7 @@ SRCS+= DeltaTree.cpp \
HTMLPrint.cpp \
HTMLRewrite.cpp \
RewriteMacros.cpp \
+ RewriteModernObjC.cpp \
RewriteObjC.cpp \
RewriteRope.cpp \
RewriteTest.cpp \
Index: src/external/bsd/llvm/lib/libclangSema/Makefile
diff -u src/external/bsd/llvm/lib/libclangSema/Makefile:1.7 src/external/bsd/llvm/lib/libclangSema/Makefile:1.8
--- src/external/bsd/llvm/lib/libclangSema/Makefile:1.7 Wed Jan 11 23:24:49 2012
+++ src/external/bsd/llvm/lib/libclangSema/Makefile Tue Feb 28 17:09:31 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.7 2012/01/11 23:24:49 joerg Exp $
+# $NetBSD: Makefile,v 1.8 2012/02/28 17:09:31 joerg Exp $
LIB= clangSema
@@ -13,7 +13,6 @@ SRCS+= AnalysisBasedWarnings.cpp \
DelayedDiagnostic.cpp \
IdentifierResolver.cpp \
JumpDiagnostics.cpp \
- MultiInitializer.cpp \
Scope.cpp \
Sema.cpp \
SemaAccess.cpp \
@@ -34,6 +33,7 @@ SRCS+= AnalysisBasedWarnings.cpp \
SemaExprMember.cpp \
SemaFixItUtils.cpp \
SemaInit.cpp \
+ SemaLambda.cpp \
SemaLookup.cpp \
SemaObjCProperty.cpp \
SemaOverload.cpp \
Index: src/external/bsd/llvm/lib/libclangStaticAnalyzerCheckers/Makefile
diff -u src/external/bsd/llvm/lib/libclangStaticAnalyzerCheckers/Makefile:1.11 src/external/bsd/llvm/lib/libclangStaticAnalyzerCheckers/Makefile:1.12
--- src/external/bsd/llvm/lib/libclangStaticAnalyzerCheckers/Makefile:1.11 Wed Jan 11 23:24:49 2012
+++ src/external/bsd/llvm/lib/libclangStaticAnalyzerCheckers/Makefile Tue Feb 28 17:09:31 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.11 2012/01/11 23:24:49 joerg Exp $
+# $NetBSD: Makefile,v 1.12 2012/02/28 17:09:31 joerg Exp $
LIB= clangStaticAnalyzerCheckers
@@ -12,9 +12,11 @@ SRCS+= AdjustedReturnValueChecker.cpp \
ArrayBoundCheckerV2.cpp \
AttrNonNullChecker.cpp \
BasicObjCFoundationChecks.cpp \
+ BoolAssignmentChecker.cpp \
BuiltinFunctionChecker.cpp \
ClangCheckers.cpp \
CStringChecker.cpp \
+ CStringSyntaxChecker.cpp \
CallAndMessageChecker.cpp \
CastSizeChecker.cpp \
CastToStructChecker.cpp \
@@ -43,6 +45,8 @@ SRCS+= AdjustedReturnValueChecker.cpp \
NoReturnFunctionChecker.cpp \
OSAtomicChecker.cpp \
ObjCAtSyncChecker.cpp \
+ ObjCContainersASTChecker.cpp \
+ ObjCContainersChecker.cpp \
ObjCSelfInitChecker.cpp \
ObjCUnusedIVarsChecker.cpp \
PointerArithChecker.cpp \
Index: src/tools/llvm/Makefile
diff -u src/tools/llvm/Makefile:1.11 src/tools/llvm/Makefile:1.12
--- src/tools/llvm/Makefile:1.11 Mon Jul 18 19:11:28 2011
+++ src/tools/llvm/Makefile Tue Feb 28 17:09:29 2012
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.11 2011/07/18 19:11:28 joerg Exp $
+# $NetBSD: Makefile,v 1.12 2012/02/28 17:09:29 joerg Exp $
.include <bsd.init.mk>
@@ -23,6 +23,7 @@ config/config.status: ${LLVM_SRCDIR}/con
--enable-targets=x86,powerpc,sparc,arm,mips \
--host=${MACHINE_GNU_PLATFORM} \
--with-c-include-dirs=/usr/include/clang-3.0:/usr/include \
+ --with-clang-srcdir=${CLANG_SRCDIR} \
--enable-optimized
# --disable-assertions
Added files:
Index: src/external/bsd/llvm/config/clang/Config/config.h
diff -u /dev/null src/external/bsd/llvm/config/clang/Config/config.h:1.1
--- /dev/null Tue Feb 28 17:09:32 2012
+++ src/external/bsd/llvm/config/clang/Config/config.h Tue Feb 28 17:09:30 2012
@@ -0,0 +1,19 @@
+/* tools/clang/include/clang/Config/config.h. Generated from config.h.in by configure. */
+/* include/clang/Config/config.h.in. */
+
+#ifndef CONFIG_H
+#define CONFIG_H
+
+/* Bug report URL. */
+#define BUG_REPORT_URL "http://llvm.org/bugs/"
+
+/* Relative directory for resource files */
+#define CLANG_RESOURCE_DIR ""
+
+/* Directory where gcc is installed. */
+#define GCC_INSTALL_PREFIX ""
+
+/* Directories clang will search for headers */
+#define C_INCLUDE_DIRS "/usr/include/clang-3.0:/usr/include"
+
+#endif
Index: src/external/bsd/llvm/lib/libLLVMVectorize/Makefile
diff -u /dev/null src/external/bsd/llvm/lib/libLLVMVectorize/Makefile:1.1
--- /dev/null Tue Feb 28 17:09:32 2012
+++ src/external/bsd/llvm/lib/libLLVMVectorize/Makefile Tue Feb 28 17:09:31 2012
@@ -0,0 +1,15 @@
+# $NetBSD: Makefile,v 1.1 2012/02/28 17:09:31 joerg Exp $
+
+LIB= LLVMVectorize
+
+.include <bsd.init.mk>
+
+.PATH: ${LLVM_SRCDIR}/lib/Transforms/Vectorize
+
+SRCS+= BBVectorize.cpp
+
+.if defined(HOSTLIB)
+.include <bsd.hostlib.mk>
+.else
+.include <bsd.lib.mk>
+.endif
Index: src/tools/llvm-lib/libLLVMVectorize/Makefile
diff -u /dev/null src/tools/llvm-lib/libLLVMVectorize/Makefile:1.1
--- /dev/null Tue Feb 28 17:09:32 2012
+++ src/tools/llvm-lib/libLLVMVectorize/Makefile Tue Feb 28 17:09:29 2012
@@ -0,0 +1,3 @@
+# $NetBSD: Makefile,v 1.1 2012/02/28 17:09:29 joerg Exp $
+
+.include <bsd.init.mk>
Index: src/external/bsd/llvm/config/llvm/Support/DataTypes.h
diff -u src/external/bsd/llvm/config/llvm/Support/DataTypes.h:1.1 src/external/bsd/llvm/config/llvm/Support/DataTypes.h:1.2
--- src/external/bsd/llvm/config/llvm/Support/DataTypes.h:1.1 Sun Feb 6 01:13:51 2011
+++ src/external/bsd/llvm/config/llvm/Support/DataTypes.h Tue Feb 28 17:09:30 2012
@@ -1,5 +1,5 @@
/* include/llvm/Support/DataTypes.h. Generated from DataTypes.h.in by configure. */
/*===-- include/System/DataTypes.h - Define fixed size types -----*- C -*-===*\
|* *|
|* The LLVM Compiler Infrastructure *|
|* *|
@@ -22,6 +22,8 @@
/* Please leave this file C-compatible. */
+/* Please keep this file in sync with DataTypes.h.cmake */
+
#ifndef SUPPORT_DATATYPES_H
#define SUPPORT_DATATYPES_H
@@ -37,17 +39,19 @@
#include <math.h>
#endif
+#ifndef _MSC_VER
+
/* Note that this header's correct operation depends on __STDC_LIMIT_MACROS
being defined. We would define it here, but in order to prevent Bad Things
happening when system headers or C++ STL headers include stdint.h before we
define it here, we define it on the g++ command line (in Makefile.rules). */
#if !defined(__STDC_LIMIT_MACROS)
-# error "Must #define __STDC_LIMIT_MACROS before #including System/DataTypes.h"
+# error "Must #define __STDC_LIMIT_MACROS before #including Support/DataTypes.h"
#endif
#if !defined(__STDC_CONSTANT_MACROS)
# error "Must #define __STDC_CONSTANT_MACROS before " \
- "#including System/DataTypes.h"
+ "#including Support/DataTypes.h"
#endif
/* Note that <inttypes.h> includes <stdint.h>, if this is a C99 system. */
@@ -88,6 +92,103 @@ typedef u_int64_t uint64_t;
#define UINT32_MAX 4294967295U
#endif
+#else /* _MSC_VER */
+/* Visual C++ doesn't provide standard integer headers, but it does provide
+ built-in data types. */
+#include <stdlib.h>
+#include <stddef.h>
+#include <sys/types.h>
+#ifdef __cplusplus
+#include <cmath>
+#else
+#include <math.h>
+#endif
+typedef __int64 int64_t;
+typedef unsigned __int64 uint64_t;
+typedef signed int int32_t;
+typedef unsigned int uint32_t;
+typedef short int16_t;
+typedef unsigned short uint16_t;
+typedef signed char int8_t;
+typedef unsigned char uint8_t;
+typedef signed int ssize_t;
+#ifndef INT8_MAX
+# define INT8_MAX 127
+#endif
+#ifndef INT8_MIN
+# define INT8_MIN -128
+#endif
+#ifndef UINT8_MAX
+# define UINT8_MAX 255
+#endif
+#ifndef INT16_MAX
+# define INT16_MAX 32767
+#endif
+#ifndef INT16_MIN
+# define INT16_MIN -32768
+#endif
+#ifndef UINT16_MAX
+# define UINT16_MAX 65535
+#endif
+#ifndef INT32_MAX
+# define INT32_MAX 2147483647
+#endif
+#ifndef INT32_MIN
+/* MSC treats -2147483648 as -(2147483648U). */
+# define INT32_MIN (-INT32_MAX - 1)
+#endif
+#ifndef UINT32_MAX
+# define UINT32_MAX 4294967295U
+#endif
+/* Certain compatibility updates to VC++ introduce the `cstdint'
+ * header, which defines the INT*_C macros. On default installs they
+ * are absent. */
+#ifndef INT8_C
+# define INT8_C(C) C##i8
+#endif
+#ifndef UINT8_C
+# define UINT8_C(C) C##ui8
+#endif
+#ifndef INT16_C
+# define INT16_C(C) C##i16
+#endif
+#ifndef UINT16_C
+# define UINT16_C(C) C##ui16
+#endif
+#ifndef INT32_C
+# define INT32_C(C) C##i32
+#endif
+#ifndef UINT32_C
+# define UINT32_C(C) C##ui32
+#endif
+#ifndef INT64_C
+# define INT64_C(C) C##i64
+#endif
+#ifndef UINT64_C
+# define UINT64_C(C) C##ui64
+#endif
+
+#ifndef PRId64
+# define PRId64 "I64d"
+#endif
+#ifndef PRIi64
+# define PRIi64 "I64i"
+#endif
+#ifndef PRIo64
+# define PRIo64 "I64o"
+#endif
+#ifndef PRIu64
+# define PRIu64 "I64u"
+#endif
+#ifndef PRIx64
+# define PRIx64 "I64x"
+#endif
+#ifndef PRIX64
+# define PRIX64 "I64X"
+#endif
+
+#endif /* _MSC_VER */
+
/* Set defaults for constants which we cannot find. */
#if !defined(INT64_MAX)
# define INT64_MAX 9223372036854775807LL
@@ -1,5 +1,5 @@
/* include/llvm/Support/DataTypes.h. Generated from DataTypes.h.in by configure. */
-/*===-- include/System/DataTypes.h - Define fixed size types -----*- C -*-===*\
+/*===-- include/Support/DataTypes.h - Define fixed size types -----*- C -*-===*\
|* *|
|* The LLVM Compiler Infrastructure *|